==> webkit2gtk_2.50.2.orig.tar.xz: webkitgtk-2.50.2/Source/WebCore/platform/ScreenOrientationManager.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ScreenOrientationLockType.h"
#include "ScreenOrientationType.h"
#include <wtf/CompletionHandler.h>
#include <wtf/RefCounted.h>
#include <wtf/WeakPtr.h>

namespace WebCore {
class ScreenOrientationManager;
class ScreenOrientationManagerObserver;
}

namespace WTF {
template<typename T> struct IsDeprecatedWeakRefSmartPointerException;
template<> struct IsDeprecatedWeakRefSmartPointerException<WebCore::ScreenOrientationManager> : std::true_type { };
template<> struct IsDeprecatedWeakRefSmartPointerException<WebCore::ScreenOrientationManagerObserver> : std::true_type { };
}

namespace WebCore {

class DeferredPromise;
class Exception;
class ScreenOrientation;

class ScreenOrientationManagerObserver : public CanMakeWeakPtr<ScreenOrientationManagerObserver> {
public:
    virtual ~ScreenOrientationManagerObserver() { }
    virtual void screenOrientationDidChange(ScreenOrientationType) = 0;
};

class ScreenOrientationManager : public CanMakeWeakPtr<ScreenOrientationManager> {
public:
    WEBCORE_EXPORT virtual ~ScreenOrientationManager();

    virtual ScreenOrientationType currentOrientation() = 0;
    virtual void lock(ScreenOrientationLockType, CompletionHandler<void(std::optional<Exception>&&)>&&) = 0;
    virtual void unlock() = 0;
    virtual void addObserver(ScreenOrientationManagerObserver&) = 0;
    virtual void removeObserver(ScreenOrientationManagerObserver&) = 0;

    void setLockPromise(ScreenOrientation&, Ref<DeferredPromise>&&);
    ScreenOrientation* lockRequester() const;
    RefPtr<DeferredPromise> takeLockPromise();

protected:
    WEBCORE_EXPORT ScreenOrientationManager();

private:
    RefPtr<DeferredPromise> m_lockPromise;
    WeakPtr<ScreenOrientation> m_lockRequester;
};

} // namespace WebCore

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/platform/ScreenOrientationManager.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/ScreenOrientationLockType.h>
#include <WebCore/ScreenOrientationType.h>
#include <wtf/AbstractRefCountedAndCanMakeWeakPtr.h>
#include <wtf/CompletionHandler.h>
#include <wtf/WeakPtr.h>

namespace WebCore {

class DeferredPromise;
class Exception;
class ScreenOrientation;

class ScreenOrientationManagerObserver : public AbstractRefCountedAndCanMakeWeakPtr<ScreenOrientationManagerObserver> {
public:
    virtual ~ScreenOrientationManagerObserver() { }
    virtual void screenOrientationDidChange(ScreenOrientationType) = 0;
};

class ScreenOrientationManager : public AbstractRefCountedAndCanMakeWeakPtr<ScreenOrientationManager> {
public:
    WEBCORE_EXPORT virtual ~ScreenOrientationManager();

    virtual ScreenOrientationType currentOrientation() = 0;
    virtual void lock(ScreenOrientationLockType, CompletionHandler<void(std::optional<Exception>&&)>&&) = 0;
    virtual void unlock() = 0;
    virtual void addObserver(ScreenOrientationManagerObserver&) = 0;
    virtual void removeObserver(ScreenOrientationManagerObserver&) = 0;

    void setLockPromise(ScreenOrientation&, Ref<DeferredPromise>&&);
    ScreenOrientation* lockRequester() const;
    RefPtr<DeferredPromise> takeLockPromise();

protected:
    WEBCORE_EXPORT ScreenOrientationManager();

private:
    RefPtr<DeferredPromise> m_lockPromise;
    WeakPtr<ScreenOrientation> m_lockRequester;
};

} // namespace WebCore
